SWDEV-439637 - Fix undefined symbol error hipTexRefGetArray & hipTexRefGetBorderColor (github id- #3382)
Change-Id: Iae1956779e84759f23011151b60a01cef0d0ef32
[ROCm/clr commit: 5303cd2740]
This commit is contained in:
zatwierdzone przez
Anusha Godavarthy Surya
rodzic
b97b245b0a
commit
78aee3d79f
@@ -907,7 +907,6 @@ typedef hipError_t (*t_hipHccModuleLaunchKernel)(hipFunction_t f, uint32_t globa
|
||||
void** extra, hipEvent_t startEvent,
|
||||
hipEvent_t stopEvent);
|
||||
typedef int (*t_hipGetStreamDeviceId)(hipStream_t stream);
|
||||
|
||||
typedef hipError_t (*t_hipDrvGraphAddMemsetNode)(hipGraphNode_t* phGraphNode, hipGraph_t hGraph,
|
||||
const hipGraphNode_t* dependencies, size_t numDependencies,
|
||||
const HIP_MEMSET_NODE_PARAMS* memsetParams, hipCtx_t ctx);
|
||||
@@ -940,6 +939,10 @@ typedef hipError_t (*t_hipGraphInstantiateWithParams)(hipGraphExec_t* pGraphExec
|
||||
hipGraphInstantiateParams* instantiateParams);
|
||||
typedef hipError_t (*t_hipExtGetLastError)();
|
||||
|
||||
typedef hipError_t (*t_hipTexRefGetBorderColor)(float* pBorderColor,
|
||||
const textureReference* texRef);
|
||||
typedef hipError_t (*t_hipTexRefGetArray)(hipArray_t* pArray, const textureReference* texRef);
|
||||
|
||||
// HIP Compiler dispatch table
|
||||
struct HipCompilerDispatchTable {
|
||||
size_t size;
|
||||
@@ -1401,4 +1404,6 @@ struct HipDispatchTable {
|
||||
t_hipGraphAddNode hipGraphAddNode_fn;
|
||||
t_hipGraphInstantiateWithParams hipGraphInstantiateWithParams_fn;
|
||||
t_hipExtGetLastError hipExtGetLastError_fn;
|
||||
t_hipTexRefGetBorderColor hipTexRefGetBorderColor_fn;
|
||||
t_hipTexRefGetArray hipTexRefGetArray_fn;
|
||||
};
|
||||
|
||||
Reference in New Issue
Block a user